@@ -2,11 +2,6 @@ import sys, re, string, time, copy, gc
 from itertools import *
 import time
 
-try:
-    from io import BytesIO
-except ImportError:
-    from StringIO import StringIO as BytesIO
-
 try:
     izip
 except NameError:
@@ -228,7 +223,7 @@ class TreeBenchMark(object):
                 for i in range(20 * TREE_FACTOR):
                     SubElement(el, tag).tail = text
         t = current_time() - t
-        return (root, t)
+        return root, t
 
     def _setup_tree2(self, text, attributes):
         "tree with 520 * TREE_FACTOR 2nd level and 26 3rd level children"
@@ -244,7 +239,7 @@ class TreeBenchMark(object):
                 for ch2 in atoz:
                     SubElement(el, "{cdefg}%s00001" % ch2).tail = text
         t = current_time() - t
-        return (root, t)
+        return root, t
 
     def _setup_tree3(self, text, attributes):
         "tree of depth 8 + TREE_FACTOR with 3 children per node"
@@ -260,7 +255,7 @@ class TreeBenchMark(object):
             child.text = text
             child.tail = text
         t = current_time() - t
-        return (root, t)
+        return root, t
 
     def _setup_tree4(self, text, attributes):
         "small tree with 26 2nd level and 2 3rd level children"
@@ -274,7 +269,7 @@ class TreeBenchMark(object):
             SubElement(el, "{cdefg}a00001", attributes).tail = text
             SubElement(el, "{cdefg}z00000", attributes).tail = text
         t = current_time() - t
-        return (root, t)
+        return root, t
 
     def benchmarks(self):
         """Returns a list of all benchmarks.
@@ -355,7 +350,7 @@ def buildSuites(benchmark_class, etrees, selected):
                               if match(b[0]) ] ]
                        for bs in benchmarks ]
 
-    return (benchmark_suites, benchmarks)
+    return benchmark_suites, benchmarks
 
 def build_treeset_name(trees, tn, an, serialized, children):
     text = {0:'-', 1:'S', 2:'U'}[tn]
