@@ -4,15 +4,13 @@
 HTML parser test cases for etree
 """
 
+from __future__ import absolute_import
+
 import unittest
 import tempfile, os, os.path, sys
 
-this_dir = os.path.dirname(__file__)
-if this_dir not in sys.path:
-    sys.path.insert(0, this_dir) # needed for Py3
-
-from common_imports import etree, html, StringIO, BytesIO, fileInTestDir, _bytes, _str
-from common_imports import SillyFileLike, HelperTestCase, write_to_file, next
+from .common_imports import etree, html, BytesIO, fileInTestDir, _bytes, _str
+from .common_imports import SillyFileLike, HelperTestCase, write_to_file, next
 
 try:
     unicode
@@ -66,6 +64,24 @@ class HtmlParserTestCase(HelperTestCase):
         self.assertEqual(_bytes('\\U00026007').decode('unicode_escape'),
                          p_text)
 
+    def test_html_ids(self):
+        parser = self.etree.HTMLParser(recover=False)
+        fromstring = self.etree.fromstring
+        html = fromstring('''
+            <html><body id="bodyID"><p id="pID"></p></body></html>
+        ''', parser=parser)
+        self.assertEqual(len(html.xpath('//p[@id="pID"]')), 1)
+        self.assertEqual(len(html.findall('.//p[@id="pID"]')), 1)
+
+    def test_html_ids_no_collect_ids(self):
+        parser = self.etree.HTMLParser(recover=False, collect_ids=False)
+        fromstring = self.etree.fromstring
+        html = fromstring('''
+            <html><body id="bodyID"><p id="pID"></p></body></html>
+        ''', parser=parser)
+        self.assertEqual(len(html.xpath('//p[@id="pID"]')), 1)
+        self.assertEqual(len(html.findall('.//p[@id="pID"]')), 1)
+
     def test_module_HTML_pretty_print(self):
         element = self.etree.HTML(self.html_str)
         self.assertEqual(self.etree.tostring(element, method="html", pretty_print=True),
@@ -179,6 +195,14 @@ class HtmlParserTestCase(HelperTestCase):
         self.assertRaises(self.etree.XMLSyntaxError,
                           parse, f, parser)
 
+    def test_module_parse_html_default_doctype(self):
+        parser = self.etree.HTMLParser(default_doctype=False)
+        d = html.fromstring('<!DOCTYPE html><h1>S</h1></html>', parser=parser)
+        self.assertEqual(d.getroottree().docinfo.doctype, '<!DOCTYPE html>')
+
+        d = html.fromstring('<html><h1>S</h1></html>', parser=parser)
+        self.assertEqual(d.getroottree().docinfo.doctype, '')
+
     def test_parse_encoding_8bit_explicit(self):
         text = _str('Søk på nettet')
         html_latin1 = (_str('<p>%s</p>') % text).encode('iso-8859-1')
@@ -230,9 +254,8 @@ class HtmlParserTestCase(HelperTestCase):
         filename = tempfile.mktemp(suffix=".html")
         write_to_file(filename, self.html_str, 'wb')
         try:
-            f = open(filename, 'rb')
-            tree = self.etree.parse(f, parser)
-            f.close()
+            with open(filename, 'rb') as f:
+                tree = self.etree.parse(f, parser)
             self.assertEqual(self.etree.tostring(tree.getroot(), method="html"),
                              self.html_str)
         finally:
@@ -291,6 +314,21 @@ class HtmlParserTestCase(HelperTestCase):
              ('end', root[1]), ('end', root)],
             events)
 
+    def test_html_iterparse_tag(self):
+        iterparse = self.etree.iterparse
+        f = BytesIO(
+            '<html><head><title>TITLE</title><body><p>P</p></body></html>')
+
+        iterator = iterparse(f, html=True, tag=["p", "title"])
+        self.assertEqual(None, iterator.root)
+
+        events = list(iterator)
+        root = iterator.root
+        self.assertTrue(root is not None)
+        self.assertEqual(
+            [('end', root[0][0]), ('end', root[1][0])],
+            events)
+
     def test_html_iterparse_stop_short(self):
         iterparse = self.etree.iterparse
         f = BytesIO(
@@ -592,6 +630,28 @@ class HtmlParserTestCase(HelperTestCase):
         self.assertEqual(self.etree.tostring(doc),
                          _bytes('<!DOCTYPE html PUBLIC "-//IETF//DTD HTML//EN">\n<html/>'))
 
+    def test_boolean_attribute(self):
+        # ability to serialize boolean attribute by setting value to None
+        form = html.Element('form')
+        form.set('novalidate', None)
+        self.assertEqual(html.tostring(form),
+                         _bytes('<form novalidate></form>'))
+        form.set('custom')
+        self.assertEqual(html.tostring(form),
+                         _bytes('<form novalidate custom></form>'))
+
+    def test_boolean_attribute_round_trip(self):
+        # ability to pass boolean attributes unmodified
+        fragment = '<tag attribute></tag>'
+        self.assertEqual(html.tostring(html.fragment_fromstring(fragment)),
+                         _bytes(fragment))
+
+    def test_boolean_attribute_xml_adds_empty_string(self):
+        # html serialized as xml converts boolean attributes to empty strings
+        fragment = '<tag attribute></tag>'
+        self.assertEqual(self.etree.tostring(html.fragment_fromstring(fragment)),
+                         _bytes('<tag attribute=""/>'))
+
 
 def test_suite():
     suite = unittest.TestSuite()
