@@ -25,7 +25,7 @@ Syntax: test.py [options] [pathname-regexp [test-regexp]]
 There are two kinds of tests:
   - unit tests (or programmer tests) test the internal workings of various
     components of the system
-  - functional tests (acceptance tests, customer tests) test only externaly
+  - functional tests (acceptance tests, customer tests) test only externally
     visible system behaviour
 
 You can choose to run unit tests (this is the default mode), functional tests
@@ -72,11 +72,6 @@ import getopt
 import unittest
 import traceback
 
-try:
-    set
-except NameError:
-    from sets import Set as set
-
 try:
     # Python >=2.7 and >=3.2
     from unittest.runner import _TextTestResult
@@ -460,8 +455,8 @@ def main(argv):
     """Main program."""
 
     # Environment
-    if sys.version_info < (2, 6):
-        stderr('%s: need Python 2.6 or later' % argv[0])
+    if sys.version_info < (2, 7):
+        stderr('%s: need Python 2.7 or later' % argv[0])
         stderr('your python is %s' % sys.version)
         return 1
 
